==> react-gui-common-1.3.176.tgz: package/src/components/base/FileUpload.js <==
/* eslint-disable react/jsx-handler-names */
/* eslint-disable react/destructuring-assignment */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Button } from 'primereact/button';
import { ProgressBar } from 'primereact/progressbar';
import DomHandler from 'primereact/components/utils/DomHandler';
import classNames from 'classnames';
import CustomMessages from '../CustomMessages';

export class FileUpload extends Component {
	constructor(props) {
		super(props);
		this.state = {
			files: [],
			msgs: [],
		};

		this.upload = this.upload.bind(this);
		this.clear = this.clear.bind(this);
		this.onFileSelect = this.onFileSelect.bind(this);
		this.onDragEnter = this.onDragEnter.bind(this);
		this.onDragOver = this.onDragOver.bind(this);
		this.onDragLeave = this.onDragLeave.bind(this);
		this.onDrop = this.onDrop.bind(this);
		this.onFocus = this.onFocus.bind(this);
		this.onBlur = this.onBlur.bind(this);
		this.onSimpleUploaderClick = this.onSimpleUploaderClick.bind(this);
	}

	hasFiles() {
		return this.state.files && this.state.files.length > 0;
	}

	isImage(file) {
		return /^image\//.test(file.type);
	}

	remove(event, index) {
		this.clearInputElement();
		const currentFiles = [...this.state.files];
		const removedFile = this.state.files[index];

		currentFiles.splice(index, 1);
		this.setState({ files: currentFiles });

		if (this.props.onRemove) {
			this.props.onRemove({
				originalEvent: event,
				file: removedFile,
			});
		}
	}

	clearInputElement() {
		this.fileInput.value = '';
		if (this.props.mode === 'basic') {
			this.fileInput.style.display = 'inline';
		}
	}

	formatSize(bytes) {
		if (bytes === 0) {
			return '0 B';
		}
		const k = 1000;
		const dm = 3;
		const sizes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
		const i = Math.floor(Math.log(bytes) / Math.log(k));

		return `${parseFloat((bytes / Math.pow(k, i)).toFixed(dm))} ${sizes[i]}`;
	}

	onFileSelect(event) {
		this.setState({ msgs: [] });
		this.files = this.state.files || [];
		const files = event.dataTransfer ? event.dataTransfer.files : event.target.files;
		for (let i = 0; i < files.length; i++) {
			const file = files[i];

			if (!this.isFileSelected(file)) {
				if (this.validate(file)) {
					if (this.isImage(file)) {
						file.objectURL = window.URL.createObjectURL(file);
					}
					this.files.push(file);
				}
			}
		}

		this.setState({ files: this.files }, () => {
			if (this.hasFiles() && this.props.auto) {
				this.upload();
			}
		});

		if (this.props.onSelect) {
			this.props.onSelect({ originalEvent: event, files });
		}

		this.clearInputElement();

		if (this.props.mode === 'basic') {
			this.fileInput.style.display = 'none';
		}
	}

	isFileSelected(file) {
		for (const sFile of this.state.files) {
			if (sFile.name + sFile.type + sFile.size === file.name + file.type + file.size) return true;
		}
		return false;
	}

	validate(file) {
		if (this.props.maxFileSize && file.size > this.props.maxFileSize) {
			const message = {
				severity: 'error',
				summary: this.props.invalidFileSizeMessageSummary.replace('{0}', file.name),
				detail: this.props.invalidFileSizeMessageDetail.replace(
					'{0}',
					this.formatSize(this.props.maxFileSize)
				),
				life: 15000,
			};

			if (this.props.mode === 'advanced') {
				this.messages.show(message);
			}

			if (this.props.onValidationFail) {
				this.props.onValidationFail(file);
			}
			console.log('validate', false);
			return false;
		}

		console.log('validate', true);
		return true;
	}

	upload() {
		if (this.props.customUpload) {
			if (this.props.uploadHandler) {
				this.props.uploadHandler({
					files: this.state.files,
				});
			}
		} else {
			this.setState({ msgs: [] });
			const xhr = new XMLHttpRequest();
			const formData = new FormData();

			if (this.props.onBeforeUpload) {
				this.props.onBeforeUpload({
					xhr,
					formData,
				});
			}

			for (const file of this.state.files) {
				formData.append(this.props.name, file, file.name);
			}

			xhr.upload.addEventListener('progress', event => {
				if (event.lengthComputable) {
					this.setState({ progress: Math.round((event.loaded * 100) / event.total) });
				}

				if (this.props.onProgress) {
					this.props.onProgress({
						originalEvent: event,
						progress: this.progress,
					});
				}
			});

			xhr.onreadystatechange = () => {
				if (xhr.readyState === 4) {
					this.setState({ progress: 0 });

					if (xhr.status >= 200 && xhr.status < 300) {
						if (this.props.onUpload) {
							this.props.onUpload({ xhr, files: this.files });
						}
					} else {
						if (this.props.onError) {
							this.props.onError({ xhr, files: this.files });
						}
					}

					this.clear();
				}
			};

			xhr.open('POST', this.props.url, true);

			if (this.props.onBeforeSend) {
				this.props.onBeforeSend({
					xhr,
					formData,
				});
			}

			xhr.withCredentials = this.props.withCredentials;

			xhr.send(formData);
		}
	}

	clear() {
		this.setState({ files: [] });
		if (this.props.onClear) {
			this.props.onClear();
		}
		this.clearInputElement();
	}

	onFocus(event) {
		DomHandler.addClass(event.currentTarget.parentElement, 'p-focus');
	}

	onBlur(event) {
		DomHandler.removeClass(event.currentTarget.parentElement, 'p-focus');
	}

	onDragEnter(event) {
		if (!this.props.disabled) {
			event.stopPropagation();
			event.preventDefault();
		}
	}

	onDragOver(event) {
		if (!this.props.disabled) {
			DomHandler.addClass(this.content, 'p-fileupload-highlight');
			event.stopPropagation();
			event.preventDefault();
		}
	}

	onDragLeave() {
		if (!this.props.disabled) {
			DomHandler.removeClass(this.content, 'p-fileupload-highlight');
		}
	}

	onDrop(event) {
		if (!this.props.disabled) {
			DomHandler.removeClass(this.content, 'p-fileupload-highlight');
			event.stopPropagation();
			event.preventDefault();

			const files = event.dataTransfer ? event.dataTransfer.files : event.target.files;
			const allowDrop = this.props.multiple || (files && files.length === 1);

			if (allowDrop) {
				this.onFileSelect(event);
			}
		}
	}

	onSimpleUploaderClick() {
		if (this.hasFiles()) {
			this.upload();
		}
	}

	renderChooseButton() {
		const className = classNames(
			'p-button p-fileupload-choose p-component p-button-text-icon-left'
		);

		return (
			<span icon="pi pi-plus" className={className}>
				<input
					id={`${this.props.id}-button`}
					ref={el => (this.fileInput = el)}
					type="file"
					onChange={this.onFileSelect}
					onFocus={this.onFocus}
					onBlur={this.onBlur}
					multiple={this.props.multiple}
					accept={this.props.accept}
					disabled={this.props.disabled}
					aria-label={this.props.ariaLabel}
					aria-labelledby={this.props.ariaLabelledBy}
					aria-describedby={this.props.ariaDescribedBy}
				/>
				<span className="p-button-icon p-button-icon-left p-clickable pi pi-fw pi-plus" />
				<span className="p-button-text p-clickable">{this.props.chooseLabel}</span>
			</span>
		);
	}

	renderFiles() {
		return (
			<div className="p-fileupload-files">
				{this.state.files.map((file, index) => {
					const preview = this.isImage(file) ? (
						<div>
							<img
								alt={file.name}
								role="presentation"
								src={file.objectURL}
								width={this.props.previewWidth}
							/>
						</div>
					) : null;
					const fileName = <div>{file.name}</div>;
					const size = <div>{this.formatSize(file.size)}</div>;
					const removeButton = (
						<div>
							<Button type="button" icon="pi pi-times" onClick={e => this.remove(e, index)} />
						</div>
					);

					return (
						<div className="p-fileupload-row" key={file.name + file.type + file.size}>
							{preview}
							{fileName}
							{size}
							{removeButton}
						</div>
					);
				})}
			</div>
		);
	}

	renderAdvanced() {
		const className = classNames('p-fileupload p-component', this.props.className);
		let uploadButton;
		let cancelButton;
		let filesList;
		let progressBar;
		const chooseButton = this.renderChooseButton();

		if (!this.props.auto) {
			uploadButton = (
				<Button
					type="button"
					label={this.props.uploadLabel}
					icon="pi pi-upload"
					onClick={this.upload}
					disabled={this.props.disabled || !this.hasFiles()}
				/>
			);
			cancelButton = (
				<Button
					type="button"
					label={this.props.cancelLabel}
					icon="pi pi-times"
					onClick={this.clear}
					disabled={this.props.disabled || !this.hasFiles()}
				/>
			);
		}

		if (this.hasFiles()) {
			filesList = this.renderFiles();
			progressBar = <ProgressBar value={this.state.progress} showValue={false} />;
		}

		return (
			<div id={this.props.id} className={className} style={this.props.style}>
				<CustomMessages ref={el => (this.messages = el)} />
				<div className="p-fileupload-buttonbar">
					{chooseButton}
					{uploadButton}
					{cancelButton}
				</div>
				<div
					ref={el => {
						this.content = el;
					}}
					className="p-fileupload-content"
					onDragEnter={this.onDragEnter}
					onDragOver={this.onDragOver}
					onDragLeave={this.onDragLeave}
					onDrop={this.onDrop}
				>
					{progressBar}
					{filesList}
				</div>
			</div>
		);
	}

	renderBasic() {
		const buttonClassName = classNames(
			'p-button p-fileupload-choose p-component p-button-text-icon-left',
			{ 'p-fileupload-choose-selected': this.hasFiles() }
		);
		const iconClassName = classNames('p-button-icon-left pi', {
			'pi-plus': !this.hasFiles() || this.props.auto,
			'pi-upload': this.hasFiles() && !this.props.auto,
		});

		return (
			<span className={buttonClassName} onMouseUp={this.onSimpleUploaderClick}>
				<span className={iconClassName} />
				<span className="p-button-text p-clickable">
					{this.props.auto
						? this.props.chooseLabel
						: this.hasFiles()
						? this.state.files[0].name
						: this.props.chooseLabel}
				</span>
				<input
					ref={el => (this.fileInput = el)}
					type="file"
					multiple={this.props.multiple}
					accept={this.props.accept}
					disabled={this.props.disabled}
					onChange={this.onFileSelect}
					onFocus={this.onFocus}
					onBlur={this.onBlur}
				/>
			</span>
		);
	}

	render() {
		if (this.props.mode === 'advanced') return this.renderAdvanced();
		else if (this.props.mode === 'basic') return this.renderBasic();
	}
}

FileUpload.defaultProps = {
	id: null,
	name: null,
	url: null,
	mode: 'advanced',
	multiple: false,
	accept: null,
	disabled: false,
	auto: false,
	maxFileSize: null,
	invalidFileSizeMessageSummary: '{0}: Invalid file size, ',
	invalidFileSizeMessageDetail: 'maximum upload size is {0}.',
	style: null,
	className: null,
	widthCredentials: false,
	previewWidth: 50,
	chooseLabel: 'Choose',
	uploadLabel: 'Upload',
	cancelLabel: 'Cancel',
	customUpload: false,
	onBeforeUpload: null,
	onBeforeSend: null,
	onUpload: null,
	onError: null,
	onClear: null,
	onSelect: null,
	onProgress: null,
	onValidationFail: null,
	uploadHandler: null,
	onRemove: null,
};

FileUpload.propTypes = {
	accept: PropTypes.string,
	ariaDescribedBy: PropTypes.string,
	ariaLabel: PropTypes.string,
	ariaLabelledBy: PropTypes.string,
	auto: PropTypes.bool,
	cancelLabel: PropTypes.string,
	chooseLabel: PropTypes.string,
	className: PropTypes.string,
	customUpload: PropTypes.bool,
	disabled: PropTypes.bool,
	id: PropTypes.string,
	invalidFileSizeMessageDetail: PropTypes.string,
	invalidFileSizeMessageSummary: PropTypes.string,
	maxFileSize: PropTypes.number,
	mode: PropTypes.string,
	multiple: PropTypes.bool,
	name: PropTypes.string,
	onBeforeSend: PropTypes.func,
	onBeforeUpload: PropTypes.func,
	onClear: PropTypes.func,
	onError: PropTypes.func,
	onProgress: PropTypes.func,
	onRemove: PropTypes.func,
	onSelect: PropTypes.func,
	onUpload: PropTypes.func,
	onValidationFail: PropTypes.func,
	previewWidth: PropTypes.number,
	style: PropTypes.object,
	uploadHandler: PropTypes.func,
	uploadLabel: PropTypes.string,
	url: PropTypes.string,
	withCredentials: PropTypes.bool,
};

export default FileUpload;

==> react-gui-common-1.3.237.tgz: package/src/components/base/FileUpload.js <==
/* eslint-disable react/jsx-handler-names */
/* eslint-disable react/destructuring-assignment */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Button } from 'primereact/button';
import { ProgressBar } from 'primereact/progressbar';
import DomHandler from 'primereact/components/utils/DomHandler';
import classNames from 'classnames';

export class FileUpload extends Component {
	constructor(props) {
		super(props);
		this.state = {
			files: [],
			msgs: [],
		};

		this.upload = this.upload.bind(this);
		this.clear = this.clear.bind(this);
		this.onFileSelect = this.onFileSelect.bind(this);
		this.onDragEnter = this.onDragEnter.bind(this);
		this.onDragOver = this.onDragOver.bind(this);
		this.onDragLeave = this.onDragLeave.bind(this);
		this.onDrop = this.onDrop.bind(this);
		this.onFocus = this.onFocus.bind(this);
		this.onBlur = this.onBlur.bind(this);
		this.onSimpleUploaderClick = this.onSimpleUploaderClick.bind(this);
	}

	hasFiles() {
		return this.state.files && this.state.files.length > 0;
	}

	isImage(file) {
		return /^image\//.test(file.type);
	}

	remove(event, index) {
		this.clearInputElement();
		const currentFiles = [...this.state.files];
		const removedFile = this.state.files[index];

		currentFiles.splice(index, 1);
		this.setState({ files: currentFiles });

		if (this.props.onRemove) {
			this.props.onRemove({
				originalEvent: event,
				file: removedFile,
			});
		}
	}

	clearInputElement() {
		this.fileInput.value = '';
		if (this.props.mode === 'basic') {
			this.fileInput.style.display = 'inline';
		}
	}

	formatSize(bytes) {
		if (bytes === 0) {
			return '0 B';
		}
		const k = 1000;
		const dm = 3;
		const sizes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
		const i = Math.floor(Math.log(bytes) / Math.log(k));

		return `${parseFloat((bytes / Math.pow(k, i)).toFixed(dm))} ${sizes[i]}`;
	}

	onFileSelect(event) {
		this.setState({ msgs: [] });
		this.files = this.state.files || [];
		const files = event.dataTransfer ? event.dataTransfer.files : event.target.files;
		for (let i = 0; i < files.length; i++) {
			const file = files[i];

			if (!this.isFileSelected(file)) {
				if (this.validate(file)) {
					if (this.isImage(file)) {
						file.objectURL = window.URL.createObjectURL(file);
					}
					this.files.push(file);
				}
			}
		}

		this.setState({ files: this.files }, () => {
			if (this.hasFiles() && this.props.auto) {
				this.upload();
			}
		});

		if (this.props.onSelect) {
			this.props.onSelect({ originalEvent: event, files });
		}

		this.clearInputElement();

		if (this.props.mode === 'basic') {
			this.fileInput.style.display = 'none';
		}
	}

	isFileSelected(file) {
		for (const sFile of this.state.files) {
			if (sFile.name + sFile.type + sFile.size === file.name + file.type + file.size) return true;
		}
		return false;
	}

	validate(file) {
		if (this.props.maxFileSize && file.size > this.props.maxFileSize) {
			const message = {
				severity: 'error',
				summary: this.props.invalidFileSizeMessageSummary.replace('{0}', file.name),
				detail: this.props.invalidFileSizeMessageDetail.replace(
					'{0}',
					this.formatSize(this.props.maxFileSize)
				),
				life: 15000,
			};

			if (this.props.mode === 'advanced') {
				this.props.messages.show(message);
			}

			if (this.props.onValidationFail) {
				this.props.onValidationFail(file);
			}
			console.log('validate', false);
			return false;
		}

		console.log('validate', true);
		return true;
	}

	upload() {
		if (this.props.customUpload) {
			if (this.props.uploadHandler) {
				this.props.uploadHandler({
					files: this.state.files,
				});
			}
		} else {
			this.setState({ msgs: [] });
			const xhr = new XMLHttpRequest();
			const formData = new FormData();

			if (this.props.onBeforeUpload) {
				this.props.onBeforeUpload({
					xhr,
					formData,
				});
			}

			for (const file of this.state.files) {
				formData.append(this.props.name, file, file.name);
			}

			xhr.upload.addEventListener('progress', event => {
				if (event.lengthComputable) {
					this.setState({ progress: Math.round((event.loaded * 100) / event.total) });
				}

				if (this.props.onProgress) {
					this.props.onProgress({
						originalEvent: event,
						progress: this.progress,
					});
				}
			});

			xhr.onreadystatechange = () => {
				if (xhr.readyState === 4) {
					this.setState({ progress: 0 });

					if (xhr.status >= 200 && xhr.status < 300) {
						if (this.props.onUpload) {
							this.props.onUpload({ xhr, files: this.files });
						}
					} else {
						if (this.props.onError) {
							this.props.onError({ xhr, files: this.files });
						}
					}

					this.clear();
				}
			};

			xhr.open('POST', this.props.url, true);

			if (this.props.onBeforeSend) {
				this.props.onBeforeSend({
					xhr,
					formData,
				});
			}

			xhr.withCredentials = this.props.withCredentials;

			xhr.send(formData);
		}
	}

	clear() {
		this.setState({ files: [] });
		if (this.props.onClear) {
			this.props.onClear();
		}
		this.clearInputElement();
	}

	onFocus(event) {
		DomHandler.addClass(event.currentTarget.parentElement, 'p-focus');
	}

	onBlur(event) {
		DomHandler.removeClass(event.currentTarget.parentElement, 'p-focus');
	}

	onDragEnter(event) {
		if (!this.props.disabled) {
			event.stopPropagation();
			event.preventDefault();
		}
	}

	onDragOver(event) {
		if (!this.props.disabled) {
			DomHandler.addClass(this.content, 'p-fileupload-highlight');
			event.stopPropagation();
			event.preventDefault();
		}
	}

	onDragLeave() {
		if (!this.props.disabled) {
			DomHandler.removeClass(this.content, 'p-fileupload-highlight');
		}
	}

	onDrop(event) {
		if (!this.props.disabled) {
			DomHandler.removeClass(this.content, 'p-fileupload-highlight');
			event.stopPropagation();
			event.preventDefault();

			const files = event.dataTransfer ? event.dataTransfer.files : event.target.files;
			const allowDrop = this.props.multiple || (files && files.length === 1);

			if (allowDrop) {
				this.onFileSelect(event);
			}
		}
	}

	onSimpleUploaderClick() {
		if (this.hasFiles()) {
			this.upload();
		}
	}

	renderChooseButton() {
		const className = classNames(
			'p-button p-fileupload-choose p-component p-button-text-icon-left'
		);

		return (
			<span icon="pi pi-plus" className={className}>
				<input
					id={`${this.props.id}-button`}
					ref={el => (this.fileInput = el)}
					type="file"
					onChange={this.onFileSelect}
					onFocus={this.onFocus}
					onBlur={this.onBlur}
					multiple={this.props.multiple}
					accept={this.props.accept}
					disabled={this.props.disabled}
					aria-label={this.props.ariaLabel}
					aria-labelledby={this.props.ariaLabelledBy}
					aria-describedby={this.props.ariaDescribedBy}
				/>
				<span className="p-button-icon p-button-icon-left p-clickable pi pi-fw pi-plus" />
				<span className="p-button-text p-clickable">{this.props.chooseLabel}</span>
			</span>
		);
	}

	renderFiles() {
		return (
			<div className="p-fileupload-files">
				{this.state.files.map((file, index) => {
					const preview = this.isImage(file) ? (
						<div>
							<img
								alt={file.name}
								role="presentation"
								src={file.objectURL}
								width={this.props.previewWidth}
							/>
						</div>
					) : null;
					const fileName = <div>{file.name}</div>;
					const size = <div>{this.formatSize(file.size)}</div>;
					const removeButton = (
						<div>
							<Button type="button" icon="pi pi-times" onClick={e => this.remove(e, index)} />
						</div>
					);

					return (
						<div className="p-fileupload-row" key={file.name + file.type + file.size}>
							{preview}
							{fileName}
							{size}
							{removeButton}
						</div>
					);
				})}
			</div>
		);
	}

	renderAdvanced() {
		const className = classNames('p-fileupload p-component', this.props.className);
		let uploadButton;
		let cancelButton;
		let filesList;
		let progressBar;
		const chooseButton = this.renderChooseButton();

		if (!this.props.auto) {
			uploadButton = (
				<Button
					type="button"
					label={this.props.uploadLabel}
					icon="pi pi-upload"
					onClick={this.upload}
					disabled={this.props.disabled || !this.hasFiles()}
				/>
			);
			cancelButton = (
				<Button
					type="button"
					label={this.props.cancelLabel}
					icon="pi pi-times"
					onClick={this.clear}
					disabled={this.props.disabled || !this.hasFiles()}
				/>
			);
		}

		if (this.hasFiles()) {
			filesList = this.renderFiles();
			progressBar = <ProgressBar value={this.state.progress} showValue={false} />;
		}

		return (
			<div id={this.props.id} className={className} style={this.props.style}>
				<div className="p-fileupload-buttonbar">
					{chooseButton}
					{uploadButton}
					{cancelButton}
				</div>
				<div
					ref={el => {
						this.content = el;
					}}
					className="p-fileupload-content"
					onDragEnter={this.onDragEnter}
					onDragOver={this.onDragOver}
					onDragLeave={this.onDragLeave}
					onDrop={this.onDrop}
				>
					{progressBar}
					{filesList}
				</div>
			</div>
		);
	}

	renderBasic() {
		const buttonClassName = classNames(
			'p-button p-fileupload-choose p-component p-button-text-icon-left',
			{ 'p-fileupload-choose-selected': this.hasFiles() }
		);
		const iconClassName = classNames('p-button-icon-left pi', {
			'pi-plus': !this.hasFiles() || this.props.auto,
			'pi-upload': this.hasFiles() && !this.props.auto,
		});

		return (
			<span className={buttonClassName} onMouseUp={this.onSimpleUploaderClick}>
				<span className={iconClassName} />
				<span className="p-button-text p-clickable">
					{this.props.auto
						? this.props.chooseLabel
						: this.hasFiles()
						? this.state.files[0].name
						: this.props.chooseLabel}
				</span>
				<input
					ref={el => (this.fileInput = el)}
					type="file"
					multiple={this.props.multiple}
					accept={this.props.accept}
					disabled={this.props.disabled}
					onChange={this.onFileSelect}
					onFocus={this.onFocus}
					onBlur={this.onBlur}
				/>
			</span>
		);
	}

	render() {
		if (this.props.mode === 'advanced') return this.renderAdvanced();
		else if (this.props.mode === 'basic') return this.renderBasic();
	}
}

FileUpload.defaultProps = {
	id: null,
	name: null,
	url: null,
	mode: 'advanced',
	multiple: false,
	accept: null,
	disabled: false,
	auto: false,
	maxFileSize: null,
	invalidFileSizeMessageSummary: '{0}: Invalid file size, ',
	invalidFileSizeMessageDetail: 'maximum upload size is {0}.',
	style: null,
	className: null,
	widthCredentials: false,
	previewWidth: 50,
	chooseLabel: 'Choose',
	uploadLabel: 'Upload',
	cancelLabel: 'Cancel',
	customUpload: false,
	onBeforeUpload: null,
	onBeforeSend: null,
	onUpload: null,
	onError: null,
	onClear: null,
	onSelect: null,
	onProgress: null,
	onValidationFail: null,
	uploadHandler: null,
	onRemove: null,
};

FileUpload.propTypes = {
	accept: PropTypes.string,
	ariaDescribedBy: PropTypes.string,
	ariaLabel: PropTypes.string,
	ariaLabelledBy: PropTypes.string,
	auto: PropTypes.bool,
	cancelLabel: PropTypes.string,
	chooseLabel: PropTypes.string,
	className: PropTypes.string,
	customUpload: PropTypes.bool,
	disabled: PropTypes.bool,
	id: PropTypes.string,
	invalidFileSizeMessageDetail: PropTypes.string,
	invalidFileSizeMessageSummary: PropTypes.string,
	maxFileSize: PropTypes.number,
	messages: PropTypes.any,
	mode: PropTypes.string,
	multiple: PropTypes.bool,
	name: PropTypes.string,
	onBeforeSend: PropTypes.func,
	onBeforeUpload: PropTypes.func,
	onClear: PropTypes.func,
	onError: PropTypes.func,
	onProgress: PropTypes.func,
	onRemove: PropTypes.func,
	onSelect: PropTypes.func,
	onUpload: PropTypes.func,
	onValidationFail: PropTypes.func,
	previewWidth: PropTypes.number,
	style: PropTypes.object,
	uploadHandler: PropTypes.func,
	uploadLabel: PropTypes.string,
	url: PropTypes.string,
	withCredentials: PropTypes.bool,
};

export default FileUpload;
